<div align="center">

# :hammer_and_wrench: CKA PyTorch examples :hammer_and_wrench:
**Some examples of how to use the package.**

---
</div>

## :pushpin: Examples
- Comparison between two models, each consisting of a stack of feed-forward networks. This is the simplest example and should be used as a starting point.
- Comparison between two randomly initialized Bert models using the HuggingFace libraries.
- Loading and plotting a previously saved CKA matrix.
